#! /usr/bin/env python

import sys
import re


# functional programming constructs
car = lambda lst: lst[0]
cdr = lambda lst: lst[1:]


def __generate_possible_words(tokens):
    """Given a set of tokens, generate all possible words
    if a character is taken out of each token."""
    if len(tokens) == 1:
        last_token = car(tokens)
        return list(last_token)

    possible = []
    subwords = __generate_possible_words(cdr(tokens))
    for char in car(tokens):
        possible += [char + subword for subword in subwords]

    return possible


def generate_possible_words(pattern):
    # treat parentheses as delimiters
    pattern = pattern.replace('(', ')')
    tokens = [token for token in pattern.split(')') if token]

    return __generate_possible_words(tokens)
            


def count_possible(pattern, dict):
    """Return the number of matches for pattern with words in dict.
    All words in dict must be of length wlen.
    pattern is a compiled RegexObject.
    """
    count = 0
    for word in dict:
        if pattern.match(word):
            count += 1

    return count


def main(argv):
    input = sys.stdin
    
    firstline = input.readline()
    L, D, N = [int(i) for i in firstline.split()]

    alien_dict = []   # all the words in the language
    for i in xrange(D):
        alien_dict.append(input.readline())

    if not all(len(word) == (L + 1) for word in alien_dict):
        raise Exception('Invalid dictionary!')

    for i in xrange(N):
        pattern = input.readline()
        re_pattern = re.compile(pattern.replace('(', '[').replace(')', ']'))
        possible = count_possible(re_pattern, alien_dict)
        print 'Case #%d: %d' % ((i + 1), possible)
    

if __name__ == '__main__':
    sys.exit(main(sys.argv))
